# PyHuTool
<p align="center">
	<a href="https://pyhutool.readthedocs.org"><img src="https://www.xujiantao.com/images/pyhutool-logo.png" width="45%"></a>
</p>
<p align="center">
	<strong>🍬A set of tools that keep Python sweet.</strong>
</p>
<p align="center">
	👉 <a href="https://pyhutool.readthedocs.org">https://pyhutool.readthedocs.org</a> 👈
</p>


PyHuTool draws lessons from Java's Hutool to reduce the learning cost of related APIs and improve work efficiency

## 📝文档 
[📘中文文档](https://pyhutool.readthedocs.org)
Full documentation available at https://pyhutool.readthedocs.org


## 🛠️包含组件
| 模块                | 介绍                                      |
| -------------------|-----------------------------------------|
| pyhutool.core        | 核心，包括文件处理、数据转换、日期、各种Util等               |
| pyhutool.gui         | 自动化库，包含按键、鼠标、截图的操作等                     |
| pyhutool.system         | 获取系统相关信息，如显示器数量，当前窗口标题，系统正在运行什么程序以及PID等 |
